@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import re
 from pathlib import Path, PurePath
 from typing import Callable, Iterable, Optional
 
@@ -149,7 +150,12 @@ class MarkdownBlock(Static):
         if token.children:
             for child in token.children:
                 if child.type == "text":
-                    content.append(child.content, style_stack[-1])
+                    content.append(
+                        # Ensure repeating spaces and/or tabs get squashed
+                        # down to a single space.
+                        re.sub(r"\s+", " ", child.content),
+                        style_stack[-1],
+                    )
                 if child.type == "hardbreak":
                     content.append("\n")
                 if child.type == "softbreak":
@@ -534,7 +540,7 @@ class MarkdownBullet(Widget):
     }
     """
 
-    symbol = reactive("\u25CF")
+    symbol = reactive("\u25cf")
     """The symbol for the bullet."""
 
     def render(self) -> Text:
@@ -675,7 +681,7 @@ class Markdown(Widget):
     | `strong` | Target text that is styled inline with strong. |
     """
 
-    BULLETS = ["\u25CF ", "▪ ", "‣ ", "• ", "⭑ "]
+    BULLETS = ["\u25cf ", "▪ ", "‣ ", "• ", "⭑ "]
 
     code_dark_theme: reactive[str] = reactive("material")
     """The theme to use for code blocks when in [dark mode][textual.app.App.dark]."""
@@ -765,9 +771,9 @@ class Markdown(Widget):
             """
             return self.markdown
 
-    def _on_mount(self, _: Mount) -> None:
+    async def _on_mount(self, _: Mount) -> None:
         if self._markdown is not None:
-            self.update(self._markdown)
+            await self.update(self._markdown)
 
     def _watch_code_dark_theme(self) -> None:
         """React to the dark theme being changed."""
